# Dangerous Android phone 0-day bugs revealed – patch or work around them now!
## Despite its usually inflexible 0-day disclosure policy, Google is keeping four mobile modem bugs semi-secret due to likely ease of exploitation.
## Information:

+ Link: https://nakedsecurity.sophos.com/2023/03/17/dangerous-android-phone-0-day-bugs-revealed-patch-or-work-around-them-now/
+ Source: Naked Security
+ Author: Paul Ducklin
+ Date published: 17 March 2023, 19:56
+ Date scraped: 27 March 2023, 12:09

## Article:
![Main article image](https://nakedsecurity.sophos.com/wp-content/uploads/sites/2/2023/03/exynos-1200.png?w=775)


Google has just revealed a fourfecta of critical [zero-day bugs](https://googleprojectzero.blogspot.com/2023/03/multiple-internet-to-baseband-remote-rce.html) affecting a wide range of Android phones, including some of its own Pixel models.


These bugs are a bit different from your usual Android vulnerabilities, which typically affect the Android operating system (which is Linux-based) or the applications that come along with it, such as Google Play, Messages or the Chrome browser.


The four bugs we’re talking about here are known as *baseband vulnerabilities*, meaning that they exist in the special mobile phone networking firmware that runs on the phone’s so-called baseband chip.


Strictly speaking, *baseband* is a term used to describe the primary, or lowest-frequency parts of an individual radio signal, in contrast to a broadband signal, which (very loosely) consists of multiple baseband signals adjusted into numerous adjacent frequency ranges and transmitted at the same time in order to increase data rates, reduce interference, share frequency spectrum more widely, complicate surveillance, or all of the above. The word *baseband* is also used metaphorically to describe the hardware chip and the associated firmware that is used to handle the actual sending and receving of radio signals in devices that can communicate wirelessly. (Somewhat confusingly, the word *baseband* typically refers to the subsystem in a phone that handles conecting to the mobile telephone network, but not to the chips and software that handle Wi-Fi or Bluetooth connections.)


## Your mobile phone’s modem


Baseband chips typically operate independently of the “non-telephone” parts of your mobile phone.


They essentially run a miniature operating system of their own, on a processor of their own, and work alongside your device’s main operating system to provide mobile network connectivity for making and answering calls, sending and receiving data, roaming on the network, and so on.


If you’re old enough to have used dialup internet, you’ll remember that you had to buy a modem (short for *modulator-and-demodulator*), which you plugged either into a serial port on the back of your PC or into an expansion slot inside it; the modem would connect to the phone network, and your PC would connect to the modem. 


Well, your mobile phone’s baseband hardware and software is, very simply, a built-in modem, usually implemented as a sub-component of what’s known as the phone’s SoC, short for *system-on-chip*.


(You can think of an SoC as a sort of “integrated integrated circuit”, where separate electronic components that used to be interconnected by mounting them in close proximity on a motherboard have been integrated still further by combining them into a single chip package.)


In fact, you’ll still see baseband processors referred to as *baseband modems*, because they still handle the business of modulating and demodulating the sending and receiving of data to and from the network.


As you can imagine, this means that your mobile device isn’t just at risk from cybercriminals via bugs in the main operating system or one of the apps you use…


…but also at risk from security vulnerabilities in the baseband subsystem.


Sometimes, baseband flaws allow an attacker not only to break into the modem itself from the internet or the phone network, but also to break into the main operating system (*moving laterally*, or *pivoting*, as the jargon calls it) from the modem.


But even if the crooks can’t get past the modem and onwards into your apps, they can almost certainly do you an enormous amount of cyberharm just by implanting malware in the baseband, such as sniffing out or diverting your network data, snooping on your text messages, tracking your phone calls, and more.


Worse still, you can’t just look at your Android version number or the version numbers of your apps to check whether you’re vulnerable or patched, because the baseband hardware you’ve got, and the firmware and patches you need for it, depend on your physical device, not on the operating system you’re running on it.


Even devices that are in all obvious respects “the same” – sold under the same brand, using the same product name, with the same model number and outward appearance – might turn out to have different baseband chips, depending on which factory assembled them or which market they were sold into.


## The new zero-days


Google’s recently discovered bugs are described as follows:



> [Bug number] CVE-2023-24033 (and three other vulnerabilities that have yet to be assigned CVE identities) allowed for internet-to-baseband remote code execution. Tests conducted by [Google] Project Zero confirm that those four vulnerabilities allow an attacker to remotely compromise a phone at the baseband level with no user interaction, and require only that the attacker know the victim’s phone number.
> 
> 
> With limited additional research and development, we believe that skilled attackers would be able to quickly create an operational exploit to compromise affected devices silently and remotely.
> 
> 


In plain English, an internet-to-baseband remote code execution hole means that criminals could inject malware or spyware over the internet into the part of your phone that sends and receives network data…


…without getting their hands on your actual device, luring you to a rogue website, persuading you to install a dubious app, waiting for you to click the wrong button in a pop-up warning, giving themselves away with a suspicious notification, or tricking you in any other way.


## 18 bugs, four kept semi-secret


There were 18 bugs in this latest batch, reported by Google in late 2022 and early 2023.


Google says that it is disclosing their existence now because the agreed time has passed since they were disclosed (Google’s timeframe is usually 90 days, or close to it), but for the four bugs above, the company is not disclosing any details, noting that:



> Due to a very rare combination of level of access these vulnerabilities provide and the speed with which we believe a reliable operational exploit could be crafted, we have decided to make a policy exception to delay disclosure for the four vulnerabilities that allow for internet-to-baseband remote code execution
> 
> 


In plain English: if we were to tell you how these bugs worked, we’d make it far too easy for cybercriminals to start doing really bad things to lots of people by sneakily implanting malware on their phones.


In other words, even Google, which has attracted controversy in the past for refusing to extend its disclosure deadlines and for openly publishing proof-of-concept code for still-unpatched zero-days, has decided to follow the spirit of its Project Zero responsible disclosure process, rather than sticking to the letter of it.


Google’s argument for generally sticking to the letter and not the spirit of its disclosure rules isn’t entirely unreasonable. By using an inflexible algorithm to decide when to reveal details of unpatched bugs, even if those details could be used for evil, the company argues that complaints of favouritism and subjectivity can be avoided, such as, “Why did company X get an extra three weeks to fix their bug, while company Y did not?”


## What to do?


The problem with bugs that are announced but not fully disclosed is that it’s difficult to answer the questions, “Am I affected? And if so, what should I do?”


Apparently, Google’s research focused on devices that used a Samsung Exynos-branded baseband modem component, but that doesn’t necessarily mean that the system-on-chip would identify or brand itself as an Exynos.


For example, Google’s recent Pixel devices use Google’s own system-on-chip, branded *Tensor*, but both the Pixel 6 and Pixel 7 are vulnerable to these still-semi-secret baseband bugs.


As a result, we can’t give you a definitive list of potentially affected devices, but Google reports (our emphasis):



> Based on information from public websites that map chipsets to devices, affected products likely include:
> 
> 
> * Mobile devices from **Samsung**, including those in the **S22, M33, M13, M12, A71, A53, A33, A21s, A13, A12 and A04** series;
> * Mobile devices from **Vivo**, including those in the **S16, S15, S6, X70, X60 and X30** series;
> * The **Pixel 6** and **Pixel 7** series of devices from **Google**; and
> * any vehicles that use the **Exynos Auto T5123** chipset.
> 
> 
> 


Google says that the baseband firmware in both the Pixel 6 and Pixel 7 was patched as part of the March 2023 Android security updates, so Pixel users should ensure they have the latest patches for their devices.


For other devices, different vendors may take different lengths of time to ship their updates, so check with your vendor or mobile provider for details.


In the meantime, these bugs can apparently be sidestepped in your device settings, if you:


* **Turn off Wi-Fi calling.**
* **Turn off Voice-over-LTE (VoLTE).**


In Google’s [words](https://googleprojectzero.blogspot.com/2023/03/multiple-internet-to-baseband-remote-rce.html), *“turning off these settings will remove the exploitation risk of these vulnerabilities.”*


If you don’t need or use these features, you may as well turn them off anyway until you know for sure what modem chip is in your phone and if it needs an update.


After all, even if your device turns out to be invulnerable or already patched, there’s no downside to not having things you don’t need.




---


*Featured [image](https://en.wikipedia.org/wiki/Exynos#/media/File:Samsung-Exynos-4412-Quad_SoC_used_in_I9300.jpg) from Wikipedia, by user [Köf3](https://commons.wikimedia.org/wiki/User:K%C3%B6f3), under a [CC BY-SA 3.0](https://creativecommons.org/licenses/by-sa/3.0/) licence.*




---





## Tags:
***CVE's***: CVE-2023-24033

### Autogenerated tags:
google android system-on-chip apps malware internet-to-baseband
