# Experts created a PoC for Apache OFBiz flaw CVE-2023-51467
## Researchers published a proof-of-concept (PoC) code for the recently disclosed critical flaw CVE-2023-51467 in the Apache OfBiz.
## Information:

+ Link: https://securityaffairs.com/157339/hacking/apache-ofbiz-poc-exploit.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 12 January 2024, 12:07
+ Date scraped: 12 January 2024, 14:03

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/01/image-22.png)


Researchers from cybersecurity firm VulnCheck have created a proof-of-concept (PoC) exploit code for the recently disclosed critical flaw [CVE-2023-51467](https://securityaffairs.com/156530/security/apache-ofbiz-auth-bypass.html) (CVSS score: 9.8) in the Apache OfBiz. 


In December, experts warned of an authentication bypass zero-day flaw that affects Apache OfBiz, an open-source Enterprise Resource Planning (ERP) system.



An attacker can trigger the vulnerability, tracked as [**CVE-2023-51467**](https://nvd.nist.gov/vuln/detail/CVE-2023-51467), to bypass authentication to achieve a simple Server-Side Request Forgery (SSRF).


The issue resides in the login functionality and results from an incomplete patch for the Pre-auth RCE vulnerability [CVE-2023-49070](https://nvd.nist.gov/vuln/detail/CVE-2023-49070) (CVSS score: 9.8).


SonicWall researchers pointed out that the Apache OfBiz is part of the supply chain of prominent software, such as Atlassian’s JIRA (used by over [120K companies](https://6sense.com/tech/productivity/jira-software-market-share)). 


*“As a result, like with many supply chain libraries, the impact of this vulnerability could be severe if leveraged by threat actors.” reads the [**report**](https://blog.sonicwall.com/en-us/2023/12/sonicwall-discovers-critical-apache-ofbiz-zero-day-authbiz/) published by SonicWall. “Our research demonstrates that this flaw could lead to the exposure of sensitive information or even the ability to execute arbitrary code as demonstrated in the short video below using version 18.12.10, where the system “ping” application is executed by an unauthenticated attacker.”*


The SonicWall researchers discovered that the magic string *requirePasswordChange=Y* is the root cause of the authentication bypass regardless of the username and password field or other parameters in an HTTP request.


For this reason, removing the XML RPC code did not completely patch the flaw.


The vulnerability has been addressed by the Apache OFbiz with the release of [version 18.12.11](https://ofbiz.apache.org/security.html) or later (commit [d8b097f](https://github.com/apache/ofbiz-framework/commit/d8b097f6717a4004acf023dfe929e0e41ad63faa) and [ee02a33](https://github.com/apache/ofbiz-framework/commit/ee02a33509589856ab1ad08399e8dcee6b0edf58)).  


VulnCheck researchers explained that the vulnerability CVE-2023-51467 can be exploited to execute a malicious payload directly into the memory.


The researchers pointed out that Apache OFBiz is not a hugely popular software. The experts queried Shodan and discovered more than 10,000 potential targets. The experts pointed out that almost all of these are honeypots. 



[![Apache OfBiz](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/01/image-22.png?resize=728%2C430&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/01/image-22.png?ssl=1)


The researchers also noticed that the [Syssrv botnet](https://cujo.com/blog/the-sysrv-botnet-and-how-it-evolved/) [has been exploiting](https://viz.greynoise.io/tag/apache-ofbiz-deserialization-rce-attempt?days=1) [CVE-2020-9496](https://nvd.nist.gov/vuln/detail/CVE-2020-9496), and [CVE-2021-29200](https://nvd.nist.gov/vuln/detail/CVE-2021-29200) in the wild. The report also remarks that OFBiz was also one of the first products to have a public [Log4Shell](https://securityaffairs.com/125577/security/log4shell-known-exploited-vulnerabilities-catalog.html) [exploit](https://attackerkb.com/topics/in9sPR2Bzt/cve-2021-44228-log4shell/rapid7-analysis).


VulnCheck published the [Go-based exploit](https://github.com/vulncheck-oss/cve-2023-51467) on GitHub that targets both Windows and Linux systems. The exploit relies on an in-memory Nashorn reverse shell as the payload


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [**Mastodon**](https://infosec.exchange/@securityaffairs)


[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, Apache OfBiz)**




---




---





## Tags:
***CVE's***: CVE-2023-51467 CVE-2023-49070 CVE-2020-9496 CVE-2021-29200

### Autogenerated tags:
ofbiz vulncheck cve-2023-51467 sonicwall
