# New Linux Bug Could Lead to User Password Leaks and Clipboard Hijacking
## A new Linux vulnerability puts user passwords at risk. It exploits the "wall" command to potentially leak passwords on Ubuntu & Debian systems.
## Information:

+ Link: https://thehackernews.com/2024/03/new-linux-bug-could-lead-to-user.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 29 March 2024, 16:19
+ Date scraped: 29 March 2024, 11:14

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjhB2LKuRnaCvnJliLGGqYcYvKyz7EkTZobVJpB2qmVQZldJaDSf9dQe9DDfIg6wTusm18LyDAu3nFbjxR5dEHT7MFi6QjPYuvS1nOcJLTyVi64CW2ITNp1_UFRl_rLILldQMsxBDGn-dbLsHOgu7zozsB3BMDoGxf2CcHrJrdMtQzEoYD01UAkkjs5A8hL/s728-rw-e365/linux.jpg)


Details have emerged about a vulnerability impacting the "wall" command of the util-linux package that could be potentially exploited by a bad actor to leak a user's password or alter the clipboard on certain Linux distributions.


The bug, tracked as CVE-2024-28085, has been codenamed **WallEscape** by security researcher Skyler Ferrante. It has been described as a case of improper neutralization of escape sequences.


"The util-linux wall command does not filter [escape sequences](https://en.wikipedia.org/wiki/Escape_sequence) from command line arguments," Ferrante [said](https://github.com/skyler-ferrante/CVE-2024-28085). "This allows unprivileged users to put arbitrary text on other users' terminals, if mesg is set to "y" and wall is setgid."


The [vulnerability](https://people.rit.edu/sjf5462/6831711781/wall_2_27_2024.txt) was introduced as part of a [commit](https://github.com/util-linux/util-linux/commit/cdd3cc7fa4cafde492039180bb47f27ab8422261) made in August 2013. 


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhdKpsEk81OwnOikxTKgpp0fKbGZ8sQlNdSutORGiIEXk9d78hZvEjybZ6zrdTr1E7zwHJVO7UGpf4_43SChOFcGBzABAYAbQwH8FEP-ZRNRH9Ik3ir0NSuFJVjuXV6rXxAIlVoF1myDrQoCsLZxwXdXv1Q_PfzZiXxNdXvhk6hfq1slZqAtCfryyb9Wz8T/s728-e365/app-d.png)](https://thehackernews.uk/EUN089)
The "wall" command is used to write a message to the terminals of all users that are currently logged in to a server, essentially allowing users with elevated permissions to [broadcast key information](https://www.baeldung.com/linux/message-a-local-user) to all local users (e.g., a system shutdown).


"wall displays a message, or the contents of a file, or otherwise its standard input, on the terminals of all currently logged in users," the man page for the Linux command [reads](https://man7.org/linux/man-pages/man1/wall.1.html). "Only the superuser can write on the terminals of users who have chosen to deny messages or are using a program which automatically denies messages."


CVE-2024-28085 essentially exploits improperly filtered escape sequences provided via command line arguments to trick users into creating a fake SUDO prompt on other users' terminals and trick them into entering their passwords.


However, for this to work, the [mesg utility](https://man7.org/linux/man-pages/man1/mesg.1.html) – which controls the ability to display messages from other users – has to be set to "y" (i.e., enabled) and the wall command is executed with setgid permissions.


CVE-2024-28085 impacts Ubuntu 22.04 and Debian Bookworm as these two criteria are met. On the other hand, CentOS is not vulnerable since the wall command does not have setgid.


"On Ubuntu 22.04, we have enough control to leak a user's password by default," Ferrante said. "The only indication of attack to the user will be an incorrect password prompt when they correctly type their password, along with their password being in their command history."


Similarly, on systems that allow wall messages to be sent, an attacker could potentially alter a user's clipboard through escape sequences on select terminals like Windows Terminal. It does not work on GNOME Terminal.


Users are advised to update to util-linux version 2.40 to mitigate against the flaw.


[![Cybersecurity](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEiq3FD_K5jS19OiNrl_zJkHFPA5uRlxhWj-jrr23FY6-XPfhWmbo9d2hGEAU7haozVp8oJP6WDTShcroe-tunJMeq5PVdoOrePEC_-bzW8DlT4Dpp7r5CvIyQxabciMuLITAu8SQT6OeFR8bKOS4GQ32wteZFU8KG6c8a54AY-I7hO5w6Pc-Fzeun9pPY4w/s728-rw-e3650/cis-d.png)](https://thehackernews.uk/cis-hardened-images-platforms)
"[CVE-2024-28085] allows unprivileged users to put arbitrary text on other users terminals, if mesg is set to y and \*wall is setgid\*," according to the [release notes](https://mirrors.edge.kernel.org/pub/linux/utils/util-linux/v2.40/v2.40-ReleaseNotes). "Not all distros are affected (e.g., CentOS, RHEL, Fedora are not; Ubuntu and Debian wall is both setgid and mesg is set to y by default)."


The disclosure comes as security researcher notselwyn [detailed](https://pwning.tech/nftables/) a use-after-free vulnerability in the [netfilter subsystem](https://thehackernews.com/2022/03/new-linux-bug-in-netfilter-firewall.html) in the Linux kernel that could be exploited to achieve local privilege escalation.


Assigned the CVE identifier [CVE-2024-1086](https://nvd.nist.gov/vuln/detail/CVE-2024-1086) (CVSS score: 7.8), the underlying issue stems from input sanitization failure of [netfilter verdicts](https://thermalcircle.de/doku.php?id=blog:linux:nftables_packet_flow_netfilter_hooks_detail), allowing a local attacker to cause a denial-of-service (DoS) condition or possibly execute arbitrary code. It has been addressed in a [commit](https://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git/commit/?id=f342de4e2f33e0e39165d8639387aa6c19dff660) pushed on January 24, 2024.


  





## Tags:
***CVE's***: CVE-2024-28085 CVE-2024-1086

### Autogenerated tags:
mesg setgid util-linux linux cve-2024-28085 ferrante ubuntu
